package com.biganto.visual.roompark.presentation.screen.deals

import android.view.View
import androidx.recyclerview.widget.LinearLayoutManager
import androidx.recyclerview.widget.RecyclerView
import butterknife.BindView
import com.biganto.visual.roompark.R
import com.biganto.visual.roompark.base.RoomParkApplication
import com.biganto.visual.roompark.base.RoomParkMainActivity
import com.biganto.visual.roompark.conductor.BigantoBaseController
import com.biganto.visual.roompark.presentation.screen.deals.util.DealsListAdapter
import com.biganto.visual.roompark.util.view_utils.grid.CeilsDecoration
import timber.log.Timber
import javax.inject.Inject

/**
 * Created by Vladislav Bogdashkin on 30.09.2019.
 */

class DealsScreenController  :
    BigantoBaseController<DealsScreenViewState
        , DealsScreen
        , DealsScreenPresenter>()
    , DealsScreen {

    override fun injectDependencies() {
        getComponent()
    }

    @BindView(R.id.favorites_cards_recycler_view)
    lateinit var favoritesRecyclerView: RecyclerView

    private fun bindRecycler() {
        favoritesRecyclerView.isNestedScrollingEnabled = true
        favoritesRecyclerView.layoutManager =
            LinearLayoutManager(activity, RecyclerView.VERTICAL, false)
        favoritesRecyclerView.adapter = DealsListAdapter()
        favoritesRecyclerView.itemAnimator = null

        if (favoritesRecyclerView.itemDecorationCount == 0)
            favoritesRecyclerView.addItemDecoration(
                CeilsDecoration(1
                    , resources?.getDimensionPixelSize(R.dimen.ceil_grid_padding))
            )
    }

    private fun setToolbar(){
        toolBar.showAll()
        toolBar.appBar.setExpanded(false,true)
        toolBar.collapsingToolbarLayout.title = "МОИ СДЕЛКИ"
        toolBar.appBar.liftOnScrollTargetViewId = R.id.favorites_cards_recycler_view
        toolBar.appBar.setLiftable(true)
        toolBar.appBarScrollable(false)
        favoritesRecyclerView.isNestedScrollingEnabled = false
    }

    @Inject
    override lateinit var injectedPresenter: DealsScreenPresenter


    override fun onViewBound(v: View) {
//        setToolbar()
        bindRecycler()
    }

    override fun render(viewState: DealsScreenViewState) {
        super.render(viewState)
        Timber.d("Render state $viewState")
        when(viewState){
            is DealsScreenViewState.Idle -> render(viewState)
            is DealsScreenViewState.DealsLoaded -> render(viewState)
        }
    }

    private fun render(viewState: DealsScreenViewState.Idle){

    }


    private fun render(viewState: DealsScreenViewState.DealsLoaded){
        (favoritesRecyclerView.adapter as DealsListAdapter).addItems(viewState.items)

    }

    private fun getComponent() = DaggerDealsScreenComponent.factory()
        .create(RoomParkApplication.component,activity as RoomParkMainActivity)
        .inject(this)

    override fun getLayoutId(): Int = R.layout.favorites_screen


}